//+------------------------------------------------------------------+
//|                                                neuro-example.mq5 |
//|                        Copyright 2012, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2012, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
#include <Trade\Trade.mqh>        //     
#include <Trade\PositionInfo.mqh> //      

//---   
input double w0=0.5;
input double w1=0.5;
input double w2=0.5;
input double w3=0.5;
input double w4=0.5;
input double w5=0.5;
input double w6=0.5;
input double w7=0.5;
input double w8=0.5;
input double w9=0.5;

int               iRSI_handle;  //     
double            iRSI_buf[];   //      

double            inputs[10];   //     
double            weight[10];   //     

double            out;          //      

string            my_symbol;    //    
ENUM_TIMEFRAMES   my_timeframe; //    
double            lot_size;     //       

CTrade            m_Trade;      //     
CPositionInfo     m_Position;   //      
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int OnInit()
  {
//---            
   my_symbol=Symbol();
//---            
   my_timeframe=PERIOD_CURRENT;
//---     
   lot_size=SymbolInfoDouble(my_symbol,SYMBOL_VOLUME_MIN);
//---      
   iRSI_handle=iRSI(my_symbol,my_timeframe,14,PRICE_CLOSE);
//---    
   if(iRSI_handle==INVALID_HANDLE)
     {
      //---   ,      ,    
      Print("    ");
      return(-1);
     }
//---     
   ChartIndicatorAdd(ChartID(),0,iRSI_handle);
//---     iRSI_buf   
   ArraySetAsSeries(iRSI_buf,true);
//---     
   weight[0]=w0;
   weight[1]=w1;
   weight[2]=w2;
   weight[3]=w3;
   weight[4]=w4;
   weight[5]=w5;
   weight[6]=w6;
   weight[7]=w7;
   weight[8]=w8;
   weight[9]=w9;
//---  0,  
   return(0);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---        
   IndicatorRelease(iRSI_handle);
//---    iRSI_buf  
   ArrayFree(iRSI_buf);
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---        
   int err1=0;
//---         iRSI_buf     
   err1=CopyBuffer(iRSI_handle,0,1,10,iRSI_buf);
//---   ,           
   if(err1<0)
     {
      Print("      ");
      return;
     }
//---
   double d1=0.0;                                 //     
   double d2=1.0;                                 //     
   double x_min=iRSI_buf[ArrayMinimum(iRSI_buf)]; //   
   double x_max=iRSI_buf[ArrayMaximum(iRSI_buf)]; //   

//---          
   for(int i=0;i<ArraySize(inputs);i++)
     {
      inputs[i]=(((iRSI_buf[i]-x_min)*(d2-d1))/(x_max-x_min))+d1;
     }
//---       out
   out=CalculateNeuron(inputs,weight);
//---      0.5
   if(out<0.5)
     {
      //---       
      if(m_Position.Select(my_symbol))
        {
         //---     Sell,   
         if(m_Position.PositionType()==POSITION_TYPE_SELL) m_Trade.PositionClose(my_symbol);
         //---      Buy,  
         if(m_Position.PositionType()==POSITION_TYPE_BUY) return;
        }
      //---   ,   ,  
      m_Trade.Buy(lot_size,my_symbol);
     }
//---        0.5
   if(out>=0.5)
     {
      //---       
      if(m_Position.Select(my_symbol))
        {
         //---     Buy,   
         if(m_Position.PositionType()==POSITION_TYPE_BUY) m_Trade.PositionClose(my_symbol);
         //---      Sell,  
         if(m_Position.PositionType()==POSITION_TYPE_SELL) return;
        }
      //---   ,   ,  
      m_Trade.Sell(lot_size,my_symbol);
     }
  }
//+------------------------------------------------------------------+
//|                                          |
//+------------------------------------------------------------------+
double CalculateNeuron(double &x[],double &w[])
  {
//---       
   double NET=0.0;
//---         
   for(int n=0;n<ArraySize(x);n++)
     {
      NET+=x[n]*w[n];
     }
//---       
   NET*=0.4;
//---           
   return(ActivateNeuron(NET));
  }
//+------------------------------------------------------------------+
//|                                           |
//+------------------------------------------------------------------+
double ActivateNeuron(double x)
  {
//---      
   double Out;
//--- 
   Out=1/(1+exp(-x));
//---    
   return(Out);
  }
//+------------------------------------------------------------------+
